---
title: '[공지] [웰컴페이먼츠] 광주/우리/하나은행 가상계좌 서비스 종료 안내'
category: 공지사항
tags:
  - 공지사항
pgCompanies:
  - 웰컴페이먼츠
searchTags:
  - 서비스 종료
  - 하나
  - 우리
  - 광주
  - 가상계좌 종료
  - 가상계좌 서비스 종료
  - 웰컴
datetime: 2024-12-26T06:40:36.121Z
---

웰컴페이먼츠>광주/우리/하나은행 가상계좌 서비스가 종료 예정인 것으로 공지되어 안내 드립니다. \
관련하여 보다 자세한 내용은 아래 본문 혹은 웰컴페이먼츠를 통해 확인하여주시기 바랍니다.

<Callout title="[웰컴페이먼츠] 광주/우리/하나은행 가상계좌 서비스 종료 안내(12/27)" content="안녕하세요. 웰컴페이먼츠 입니다.

웰컴페이먼츠 전자결제 서비스를 이용해주셔서 감사합니다.
광주/우리/하나은행 가상계좌 서비스 종료 예정으로 안내 드립니다.
업무에 참고 부탁 드립니다.
감사합니다.
=====================================================================
- 내용 : 광주/우리/하나은행 가상계좌 서비스 종료
- 종료일시 : 2024-12-27(금) 12:00
- 상세
√ 광주/우리/하나은행 외 타 은행 가상계좌 사용 가능
√ 당사 결제창 內 가상계좌 은행 선택 시 '광주/우리/하나은행' 제외" />
